log_ipv4_interface_status()
{
  echo "Configured IPv4 addresses on ${interface}:" >${tmpInterfaceStatus}
  ip -4 addr show dev ${interface} | grep inet >>${tmpInterfaceStatus}
  echo "Configured IPv4 routes on ${interface}:" >>${tmpInterfaceStatus}
  ip -4 route show dev ${interface} >>${tmpInterfaceStatus}
  logger -p ${LOGFACILITY}.notice -t "NET [$$]" <${tmpInterfaceStatus}
}

log_ipv6_interface_status()
{
  echo "Configured IPv6 addresses on eth0:" >${tmpInterfaceStatus}
  ip -6 addr show dev eth0 | grep inet6 >>${tmpInterfaceStatus}
  echo "Configured IPv6 routes on eth0:" >>${tmpInterfaceStatus}
  ip -6 route show dev eth0 >>${tmpInterfaceStatus}
  logger -p ${LOGFACILITY}.notice -t "NET6 [$$]" <${tmpInterfaceStatus}
}

# Create link local address from MAC address
make_link_local_from_mac()
{
  ifconfig eth0 | grep 'HWaddr' | 
  awk '
  {
    mac_address=$NF
    printf("FE80::")
    split(mac_address, array, ":")
    for (i=1; i<=6; i++)
    {
      if ((i==3)||(i==5))
      {
        printf(":")
      }
      if (i==1)
      {
        first_byte=array[i]
        first_byte=sprintf("0x%s", first_byte)
        decimal=sprintf("%d", first_byte)
        bit_set=(decimal/2)%2
        if (bit_set==0)
        {
          printf("%x", decimal+=2)
        }
        else
        {
          printf("%x", decimal-=2)
        }
      }
      else
      {
        printf("%s", array[i])
        if (i==3)
        {
          printf("FF:FE")
        }
      }
    }
  }'
}

# Recover link local address
recover_link_local()
{
  IFS=' /'
  line=`ip -f inet6 addr show scope link | grep 'scope link'`
  if [ "${line}" ]; then
    set ${line}
    IFS=' '
    export new_ip6_address_link_local=$2
    export new_ip6_prefixlen_link_local=$3
  else
    IFS=' '
  fi
  if [ -z "${new_ip6_address_link_local}" -o -z "${new_ip6_prefixlen_link_local}" ]; then
    # Lost link local address, recreate
    export new_ip6_ipaddress_link_local=$(make_link_local_from_mac)
    export new_ip6_prefixlen_link_local=64
    logmessage "reason: ${reason}: \"ip -6 addr add ${new_ip6_address_link_local}/${new_ip6_prefixlen_link_local} scope link dev eth0\""
    ip -6 addr add ${new_ip6_address_link_local}/${new_ip6_prefixlen_link_local} scope link dev eth0
  fi
}
### network-functions start
# Check host name by using command hostname
need_hostname ()
{
  CHECK_HOSTNAME=$(hostname)
  if [ -z "$CHECK_HOSTNAME" ] || [ "$CHECK_HOSTNAME" = "(none)" ] || [ "$CHECK_HOSTNAME" = "localhost" ] || [ "$CHECK_HOSTNAME" = "localhost.localdomain" ]; then
    return 0
  else
    return 1
  fi
}

### network-functions end

save_previous()
{
  origfile="${1}"
  savefile="${SAVEDIR}/${origfile##*/}.premanual.${interface}"

  if [ ! -d ${SAVEDIR} ]; then
    mkdir -p ${SAVEDIR}
  fi

  if [ -e ${origfile} ]; then
    cp ${origfile} ${savefile}
    rm -f ${origfile}
  else
    echo > ${savefile}
  fi
}

deconfigureIpv4Interface()
{
  if [ "${alias_ip_address}" ]; then
    # Turn off alias interface
    logmessage "reason: ${reason}: \"ip link set ${interface}:0 down\""
    ip link set ${interface}:0 down
    network_parameter_changed=1
  fi

  if [ "${old_ip_address}" ]; then
    # Shut down interface, which will delete routes and clear arp cache.
    logmessage "reason: ${reason}: \"ip -4 addr flush dev ${interface}\""
    ip -4 addr flush dev ${interface} >/dev/null 2>&1
    # Do not set link down, because IPv6 may be need them
    # logmessage "reason: ${reason}: \"ip link set ${interface} down\""
    # ip link set ${interface} down
    network_parameter_changed=1
  fi

  if [ "${alias_ip_address}" ]; then
    logmessage "reason: ${reason}: \"ip -4 addr add ${alias_ip_address}/${alias_prefix} dev ${interface}:0\""
    ip -4 addr add ${alias_ip_address}/${alias_prefix} dev ${interface}:0
    logmessage "reason: ${reason}: \"ip -4 route replace ${alias_ip_address}/32 ${interface}:0\""
    ip -4 route replace ${alias_ip_address}/32 ${interface}:0
    network_parameter_changed=1
  fi
}
